<?php
define("MSG_BAD_CREDENTIALS","提供的凭证 (登陆名或密码) 是无效的。");
define("MSG_BAD_THRESHOLD_VALUE","对于区域： %s 为无效的阈值 %s");
define("MSG_BAD_ROTAU_IP","无法使用IP地址％s连接到ROTAU");
define("MSG_CHINESE","中文");
define("MSG_CONNECTION","连接");
define("MSG_COPYRIGHT_SHORT","版权 © 2020 VIAVI。 版权所有。");
define("MSG_ENGLISH","English");
define("MSG_ERROR_ADD_LOCALISATION_ERROR","添加本地化出错"); 
define("MSG_ERROR_ALARM_UNDEFINED","未定义的警报");
define("MSG_ERROR_ALARM_FETCH_FAILED","获取告警失败：");
define("MSG_ERROR_APPLY_DATABASE_PATCH_FAILURE","数据库补丁应用失败！");
define("MSG_ERROR_CLEAR_TEST_ALARM","消除测试告警失败！");
define("MSG_ERROR_COMMIT_TRANSACTION","由于响应提交失败导致保存操作失败！");
define("MSG_ERROR_CONNECTION_FAILED","连接失败！");
define("MSG_ERROR_COPY_FAILED","中文件复制失败！");
define("MSG_ERROR_COULD_NOT_ACQUIRE_LOCK","获取锁定失败！");
define("MSG_ERROR_COULD_NOT_CREATE_FILE","不能创建文件：");
define("MSG_ERROR_COULD_NOT_CREATE_SNAPSHOT","不能创建抓屏文件！");
define("MSG_ERROR_COULD_NOT_CREATE_BACKUP","不能创建OTU备份！");
define("MSG_ERROR_COULD_NOT_CREATE_GPS_FILE","无法创建GPS文件!");
define("MSG_ERROR_CREATE_DATABASE_MODEL_FAILURE","不能创建数据库模式！");
define("MSG_ERROR_DELETE_LINK","移除链路失败！");
define("MSG_ERROR_DELETE_OPTICAL_ALARM_FAILED","删除测试中的告警失败！");
define("MSG_ERROR_DELETE_OPTICAL_ALARM_ON_TEST_FAILED","删除%d测试中的告警失败！");
define("MSG_ERROR_DELETE_TEST","移除测试失败！");
define("MSG_ERROR_DTO_NOT_FOUND","未找到详细的测试目标类型。");
define("MSG_ERROR_DTO_NOT_MAPPED","已知数据未映射入数据库！");
define("MSG_ERROR_DTO_PROPERTY_NOT_FOUND","未找到类型%s 的属性%s 。");
define("MSG_ERROR_EXECUTE_STATEMENT","执行语句失败！");
define("MSG_ERROR_FAILED_TO_CHANGE_USER_PASSWORD","修改用户密码失败！");
define("MSG_ERROR_FAILED_TO_UPDATE_USER_PASSWORD_FILE","更新用户密码文件失败！");
define("MSG_ERROR_FILE_NOT_FOUND","未找到文件！");
define("MSG_ERROR_INCOHERENT_FONCTION","函数不一致！"); 
define("MSG_ERROR_INVALID_ALARM_NAME","告警取回失败，无效的文件名：");
define("MSG_ERROR_INVALID_CONFIG","介质参数不正确。");
define("MSG_ERROR_INVALID_FILE","无效文件！");
define("MSG_ERROR_INVALID_HOST_NAME","无效的主机名称：不能为空且不能少于28个字母！");
define("MSG_ERROR_INVALID_IPV4","无效的Ipv4地址！");
define("MSG_ERROR_INVALID_IPV4GATEWAY","无效的Ipv4网关地址！");
define("MSG_ERROR_INVALID_IPV4SUBNET","无效的IPv4子网掩码地址 !");
define("MSG_ERROR_INVALID_IPV6","无效的Ipv6地址！");
define("MSG_ERROR_INVALID_IPV6GATEWAY","无效的Ipv6网关地址！");
define("MSG_ERROR_INVALID_LINK_ID","无效的链路标识符！");
define("MSG_ERROR_INVALID_LINK_NAME","无效的链路名称：不能为空且不能少于80个字母！");
define("MSG_ERROR_INVALID_MODEM_TYPE","无效的调制解调器类型！");
define("MSG_ERROR_INVALID_MODULE_SELECTED","选择的模块标识符无效。");
define("MSG_ERROR_INVALID_OPERATION_STATUS","与预期不符的运行结果！");
define("MSG_ERROR_INVALID_PORT_OUT","无效的端口！");
define("MSG_ERROR_INVALID_PORT","端口无效!");
define("MSG_ERROR_INVALID_TEST_THRESHOLD_PARAMETERS","无效的阈值参数！");
define("MSG_ERROR_INVALID_USER_NEW_CREDENTIALS","无效的新用户凭证！");
define("MSG_ERROR_IO_EXCEPTION","输入/输出错误！");
define("MSG_ERROR_LAST_MARKER_BADLY_SET","最后的标记放置有问题！");
define("MSG_ERROR_LINK_ALREADY_EXIST","该链路已经存在（或它正在被移除）！");
define("MSG_ERROR_LINK_HARDWARE_CONFIG","链路不能被添加，因为OTDR模块或开关的配置是无效的！");
define("MSG_ERROR_LINK_NO_MODULE","未设置OTDR模块！");
define("MSG_ERROR_LINK_NOT_FOUND","未找到链路！");
define("MSG_ERROR_LINK_UNKNOWN","未知链路！"); 
define("MSG_ERROR_MEASURE_BAD_TIME","测试不能正常开始，因为测试时间设置无效！");
define("MSG_ERROR_MEASURE_BAD_TIMESLOT","测试不能正常开始，因为我们正处于非工作期间（时隙）");
define("MSG_ERROR_MEASURE_FAILED","开启测试失败！");
define("MSG_ERROR_MEASURE_NOT_PROGRAMMED","测试不能被启动！");
define("MSG_ERROR_MEDIA","失败：");
define("MSG_ERROR_MISSING_TEST_THRESHOLD_PARAMETERS","测试阈值参数丢失！");
define("MSG_ERROR_MISSING_OTDR_TRACE","未找到OTDR曲线！");
define("MSG_ERROR_MODEM_NOT_AVAILABLE","无法获得调制解调器！");
define("MSG_ERROR_MOD_MISSING","模块丢失！"); 
define("MSG_ERROR_NO_BACKUP_FOUND","恢复出错，备份文件未找到！");
define("MSG_ERROR_NO_LINE_STRING","没有协调KML文件中找到!");
define("MSG_ERROR_NO_LINE_STRING_COORDINATES","No coordinate found in kml file!");
define("MSG_ERROR_NO_PLACEMARK","类型PlaceMarkM没有标在KML文件中找到");
define("MSG_ERROR_ONE_MEASURE_ON_DEMAND","同一时刻只有一个测试可以被开启！");
define("MSG_ERROR_ONE_TEST_ON_DEMAND","同一时刻只有一个点名测试可以被开启！");
define("MSG_ERROR_ONLY_ONE_TEST_SETUP","同一时刻只有一个监测测试可以被设置！");
define("MSG_ERROR_OPENING_DATABASE","打开数据库失败！");
define("MSG_ERROR_OPENING_SOCKET","连接OTU应用失败！");
define("MSG_ERROR_OPENING_TRANSACTION","由于响应开启失败导致保存操作失败！");
define("MSG_ERROR_OPERATION_ALLREADY_RUNNING","操作失败，已经有操作在运行！");
define("MSG_ERROR_OPTION_MODEM_NOT_SET","调制解调器选项未设置！");
define("MSG_ERROR_OTU_APPLICATION_NOT_AVAILABLE","不能获取OTU应用！");
define("MSG_ERROR_OTU_APPLICATION_STARTING","OTU应用正在启动...");
define("MSG_ERROR_OTU_APPLICATION_REBOOTING","OTU应用正在重启...");
define("MSG_ERROR_OTU_APPLICATION_RESCUE","OTU在“拯救”模式。");
define("MSG_ERROR_OTU_APPLICATION_UPGRADE","OTU应用正在升级...");
define("MSG_ERROR_OTU_AUTHENTIFICATION_FAILURE","对OTU程序认证失败！");
define("MSG_ERROR_PARAM_MISSING","参数丢失！"); 
define("MSG_ERROR_PORT_OTU","查询OTU应用端口错误！");
define("MSG_ERROR_READING_APC","读取共享内存错误！");
define("MSG_ERROR_READING_SOCKET","与OTU应用通信失败！");
define("MSG_ERROR_REG_MEAS_FAILED","测试注册失败！"); 
define("MSG_ERROR_REF_FILE_PARMETER_ERROR","参考文件参数错误！");
define("MSG_ERROR_REMOTE_HOST_ATTEMPT_TO_SEND_DATA","远程主机尝试发送数据!");
define("MSG_ERROR_ROLLBACK_TRANSACTION","取消保存操作失败！");
define("MSG_ERROR_SAA_ALLREADY_RUNNING","设置失败, SmartAccessAnywhere设置已经在运行！");
define("MSG_ERROR_SAA_CONNECTION_FAILED","打开SmartAccessAnywhere连接失败！");
define("MSG_ERROR_SNMP_INVALID_COMMUNITY","无效的区域！");
define("MSG_ERROR_SNMP_INVALID_HEARTBEAT_PERIOD","无效的SNMP心跳周期");
define("MSG_ERROR_SNMP_INVALID_PORT","无效的端口！");
define("MSG_ERROR_SNMP_INVALID_SERVER_NAME","无效的管理员名称或地址！");
define("MSG_ERROR_SNMP_INVALID_TEST_MESSAGE","无效的采集信息。");
define("MSG_ERROR_START_EMAIL_TEST","发送邮件失败：");
define("MSG_ERROR_START_SMS_TEST","发送短信失败：");
define("MSG_ERROR_START_MEASURE","开启测试失败！");
define("MSG_ERROR_STOP_MEASURE","停止测试失败！");
define("MSG_ERROR_SWITCH_BUFFER_ERROR","错误的开关缓存！"); 
define("MSG_ERROR_SWITCH_BUFFER_SIZE","错误的开关缓存大小！"); 
define("MSG_ERROR_SYSTEM_USER_PASSWORD_CANNOT_BE_CHANGED","系统的用户密码不能被修改！");
define("MSG_ERROR_TABLE_NOT_FOUND","未找到数据库表！");
define("MSG_ERROR_TEST_ADD_ERROR","添加测试出错！");    
define("MSG_ERROR_TEST_ADD_LOC","本地化测试问题！");
define("MSG_ERROR_TEST_ALLOCATE_MEMORY","测试内存分配问题！");
define("MSG_ERROR_TEST_ALREADY_EXIST","链路上已经存在一个测试或该测试正在被移除！");
define("MSG_ERROR_TEST_BAD_MARKER_BUFFER","测试中坏的标记缓存！");
define("MSG_ERROR_TEST_BAD_TIMESLOT","测试不能正常开始，因为我们正处于非工作期间（时隙）！");
define("MSG_ERROR_TEST_FAILED","开启点名测试失败！");
define("MSG_ERROR_TEST_FUNCT","测试函数不一致！");
define("MSG_ERROR_TEST_FUNCT_MISS","测试函数丢失！");
define("MSG_ERROR_TEST_MISS_LINK","测试链路丢失！");
define("MSG_ERROR_TEST_MISS_REF_TRACE","OTDR参考曲线丢失！");
define("MSG_ERROR_TEST_NO_PARAM","测试参数丢失！");
define("MSG_ERROR_TEST_NOT_FOUND","未找到监测测试！");
define("MSG_ERROR_TEST_NOT_PROGRAMMED","测试不能被执行！");
define("MSG_ERROR_TEST_OK","添加测试成功！");
define("MSG_ERROR_TEST_REF_PARAM","在测试OTDR曲线参数问题！");
define("MSG_ERROR_TEST_SAVE_CONFIG","保存测试配置问题！");
define("MSG_ERROR_TEST_SAVE_DESC","保存测试描述问题！");
define("MSG_ERROR_TEST_SAVE_INFO","保存测试信息问题！");
define("MSG_ERROR_TEST_SIZE_BUFFER_MARKER","错误的标记缓存大小！");
define("MSG_ERROR_TEST_TEST_RUNNING","测试正在运行，不能修改测试！");
define("MSG_ERROR_TEST_TOO_MUCH_LOC","曲线定位过多！");
define("MSG_ERROR_TEST_TOO_MUCH_TESTS","测试过多！");
define("MSG_ERROR_TEST_TYPE","未知的测试类型！");
define("MSG_ERROR_TEST_UNDEFINED_TEST","未定义测试！");
define("MSG_ERROR_TEST_UNDEFINED","未定义测试错误！");
define("MSG_ERROR_TEST_UPDATE_FAILED","测试更新失败！");
define("MSG_ERROR_TOO_MANY_LINE_STRING","KML文件必须包含只有一个路由一个的LineString");
define("MSG_ERROR_UNDEFINED","未定义错误！"); 
define("MSG_ERROR_USER_PASSWORD_NOT_FOUND","未找到已设定密码用户！");
define("MSG_ERROR_WRITING_APC","写入共享内存错误！");
define("MSG_ERROR_WRITTING_SOCKET","OTU程序套接字写入错误！");
define("MSG_ERROR_WRONG_FONCTION","错误的函数模块！"); 
define("MSG_ERROR_WRONG_LASER","错误的激光器！"); 
define("MSG_ERROR_WRONG_PULSE","错误的脉宽！"); 
define("MSG_ERROR_WRONG_RANGE","错误的范围！"); 
define("MSG_ERROR_WRONG_RES","错误的分辨率！"); 
define("MSG_FRENCH","Français");
define("MSG_INVALID_LOG_LEVEL_PARAMETER","无效的日志级别参数，应该是：%s");
define("MSG_INVALID_VALUE_EXCEPTION","无效的参数值：%s");
define("MSG_INVALID_STATUS","无效的操作状态！");
define("MSG_IO_EXCEPTION","输入/输出磁盘错误！");
define("MSG_LANGUAGE","语言");
define("MSG_LINK","链路");
define("MSG_LOGIN","登录名");
define("MSG_LOGIN_WINDOW_TITLE","登录");
define("MSG_MEAS_ADD_OK","添加测量成功！"); 
define("MSG_MEASURE_AVAILABLE","测量结果可获取。");
define("MSG_MEASURE_INIT","测量正在初始化中...");
define("MSG_MEASURE_IN_PROGRESS","正在测量中...");
define("MSG_MEASURE_WAITING","请稍等，测量正在开始中...");
define("MSG_NO_JS","要启动应用程序需要JavaScript。请在您的浏览器选项中激活JavaScript。");
define("MSG_PORT","端口");
define("MSG_PARSER_COMMAND_FAILURE","命令执行失败！");
define("MSG_PARSER_COMMAND_TIMEOUT","命令执行失败：内部OTU连接失败！");
define("MSG_PASSWORD","密码");
// define("MSG_SEND_SMS_MESSAGE","OTU发送的测试短信：%s");
// define("MSG_SEND_SNMP_MESSAGE","OTU发送的测试：%s");
define("MSG_SPLASH_SCREEN_MESSAGE","正在加载中...");
define("MSG_SOCKET_ERROR","OTU程序套接字错误！");
// define("MSG_TEST_EMAIL","OTU发送的测试：");

//OTU resources
define("OTU_RES_NAME_BASE","OTU");   // Associes a la ressource UNIT
define("OTU_RES_NAME_EMAIL","邮件");
define("OTU_RES_NAME_EXTERNAL_OTAU","外部的OTAU");
define("OTU_RES_NAME_INTERNAL_OTAU","内部的OTAU");
define("OTU_RES_NAME_MODEM","调制解调器");
define("OTU_RES_NAME_NETWORK","网络");   	   // Associes a la ressource COM
define("OTU_RES_NAME_NETWORK_MODEM","网络调制解调器");
define("OTU_RES_NAME_OPTICAL_MODULE","光模块");
define("OTU_RES_NAME_RELAY_CARD","继电器卡");
define("OTU_RES_NAME_SERVER","服务器");
define("OTU_RES_NAME_SMS","短信");
define("OTU_RES_NAME_UNKNOWN","未知的");
define("OTU_RES_TIMESTAMP","时间戳");
define("OTU_RES_SEVERITY","严重性");
define("OTU_RES_LINK","光纤");
define("OTU_RES_DESCRIPTION","描写");

//OTU alarms
define("ACQUISITION_TIME","采集时间");
define("ALARM_SWITCH","光开关内部错误");
define("ALARM_MODULE","OTDR模块内部错误");
define("AUTOTEST_TEST","自动测试错误");
define("BACK_TO_NORMAL_STATE","恢复到正常状态");
define("END_OF_SURVEY","调查结束");
define("HARD_DISK_FREE_SPACE","硬盘空间不足");
define("HEART_BEAT_SENT_TO_ONMS","'心跳'信号发送给ONMS");
define("INCOHERENCE_PROBLEM_WITH_RAMAN_ACQUISITION_MODE","与拉曼激光器采集方式不一致");
define("INITIALISATION_FAILURE_DUE_TO_HARDWARE","由硬件引起的初始化失败");
define("INITIALISATION_FAILURE_DUE_TO_SOFTWARE","软件问题");
define("INJECTION_FAILURE","注入失败");
define("INNER_APPLICATION_COMMUNICATION_PROBLEM","OTU内部应用通信问题");
define("LINK_BREAK","光纤断裂");
define("LINKS_BACK_TO_AVAILABLE","链路重新可用。");
define("LOCAL_MODE","本地模式");
define("MISSING_REFERENCE_FILE","参考曲线文件丢失");
define("MODULE_AUTOCONFIGURATION","OTDR模块参数自动配置");
define("MODULE_TEMPERATURE","模块的温度");
define("MONITORING_CYCLE","监测周期");
define("MONITORING_TEST_DRIFT","监控测试曲线变化");
define("NO_PROBLEM_DETECTED","未检测到问题");
define("NON_REFLECTIVE_FAILURE","非反射事件");
define("OTDR_TRACE_STORAGE","OTDR曲线存储问题");
define("OTU_ALARM","告警%s");
define("OTU_ALARM_CONFIRMEE","确认的告警");
define("OTU_ALARM_GENERIC_MESSAGE","一般消息"); 
define("OTU_ALARM_NON_CONFIRMEE","未确认的告警"); 
define("OTU_ALARM_OVERFLOW","溢出告警");
define("OTU_ALARM_REBUID_CLEAR","重建后清除的告警"); 
define("OTU_ALARM_HDD_FAILED","硬盘故障");
define("OTU_ALARM_HDD_FAILED_USE_BACKUP","硬盘故障, 使用备份");
define("OTU_ALARM_SEQ_STOPPED","排序器停止");
define("OTU_ALARM_CLEAR","清除");
define("OTU_ALARM_CRITICAL","危急的");
define("OTU_ALARM_INDETERMINATE","不明确的");
define("OTU_ALARM_MAJOR","重要的");
define("OTU_ALARM_MINOR","次要的");
define("OTU_ALARM_WARNING","告警");
define("PEAK","峰");
define("PERSISTENT_FAILURE","持续的失败");
define("PON_FAILURE","PON测试失败");
define("OTU_SYST_ALARM_POWER_FAILURE","电源（检测）失败");
define("OTU_SYST_REFERENCE_DRIFT_FAILURE","参考迹线漂移");
define("RAMAN_POWER_DETECTION","拉曼激光器功率检测");
define("RAMAN_POWER_DECREASE","拉曼激光器功率下降");
define("REBOOT","重启");
define("REFLECTIVE_FAILURE","反射事件检测失败");
define("SIGNAL_DETECTED_ON_FIBER","光纤上检测到的信号");
define("SPLICE_FAILURE","熔接事件检测失败");
define("SWITCH_AUTOCONFIGURATION","光开关自动配置");
define("SYSTEM_FILE","系统文件");
define("TEMPORARY_PROBLEM","临时性问题");
define("TEST_MEDIA","介质测试");
define("TIMEOUT_ON_MONITORING_TEST_CYCLE","监测周期内超时");
define("THRESHOLD_LEVEL_EXCEEDED","超过阈值");
define("CONNECTOR_FAILURE","连接器");
define("CONNECTOR_FIBER_CUT_FAILURE","光纤切割（连接器)");
define("CONNECTOR_ATTENUATION_FAILURE","超过阈值 (连接器)");
define("SPLICE_BREAK","接头损坏或APC跳线断开");
define("CONNECTOR_BREAK","跳线断开或过度弯曲");
define("FIBER_BREAK","纤维断裂");
define("SPLICE_ATTENUATION","接头或APC跳线上的光纤弯曲");
define("CONNECTOR_ATTENUATION","跳线弯曲，脏，松");
define("FIBER_ATTENUATION","纤维弯曲");
define("UNKNOW_ALARM","未知的告警");
define("UNKNOWN_CAUSE","未知的原因");
?>
